@@ -1,14 +1,16 @@
 """ Util functions to assist in detection.
 """
+import glob
+import imp
+import inspect
 import logging
-import subprocess
-from subprocess import CalledProcessError
-from subprocess import PIPE
-from subprocess import Popen
-
+import os
 import psutil
+import subprocess
 
 from monasca_setup import agent_config
+from plugin import Plugin
+from subprocess import Popen, PIPE, CalledProcessError
 
 log = logging.getLogger(__name__)
 
@@ -32,15 +34,45 @@ except AttributeError:
         return output
 
 
+def find_plugins(custom_path):
+    """ Find and import all detection plugins. It will look in detection/plugins dir of the code as well as custom_path
+
+    :param custom_path: An additional path to search for detection plugins
+    :return: A list of imported detection plugin classes.
+    """
+
+    # This was adapted from what monasca_agent.common.util.load_check_directory
+    plugin_paths = glob.glob(os.path.join(os.path.dirname(os.path.realpath(__file__)), 'plugins', '*.py'))
+    plugin_paths.extend(glob.glob(os.path.join(custom_path, '*.py')))
+
+    plugins = []
+
+    for plugin_path in plugin_paths:
+        if os.path.basename(plugin_path) == '__init__.py':
+            continue
+        try:
+            plugin = imp.load_source(os.path.splitext(os.path.basename(plugin_path))[0], plugin_path)
+        except Exception:
+            log.exception('Unable to import detection plugin {0}'.format(plugin_path))
+
+        # Verify this is a subclass of Plugin
+        classes = inspect.getmembers(plugin, inspect.isclass)
+        for _, clsmember in classes:
+            if Plugin == clsmember:
+                continue
+            if issubclass(clsmember, Plugin):
+                plugins.append(clsmember)
+
+    return plugins
+
+
 def find_process_cmdline(search_string):
     """Simple function to search running process for one with cmdline containing.
     """
     for process in psutil.process_iter():
-        try:
-            if search_string in ' '.join(process.cmdline()):
+        for arg in process.cmdline():
+            if arg.find(search_string) != -1:
                 return process
-        except psutil.NoSuchProcess:
-            continue
 
     return None
 
@@ -49,11 +81,8 @@ def find_process_name(pname):
     """Simple function to search running process for one with pname.
     """
     for process in psutil.process_iter():
-        try:
-            if pname == process.name():
-                return process
-        except psutil.NoSuchProcess:
-            continue
+        if pname == process.name():
+            return process
 
     return None
 
@@ -65,16 +94,12 @@ def find_addr_listening_on_port(port):
             return conn.laddr[0].lstrip("::ffff:")
 
 
-def watch_process(search_strings, service=None, component=None,
-                  exact_match=True, detailed=False, process_name=None):
+def watch_process(search_strings, service=None, component=None, exact_match=True, detailed=False):
     """Takes a list of process search strings and returns a Plugins object with the config set.
         This was built as a helper as many plugins setup process watching
     """
     config = agent_config.Plugins()
-
-    # Fallback to default process_name strategy if process_name is not defined
-    process_name = process_name if process_name else search_strings[0]
-    parameters = {'name': process_name,
+    parameters = {'name': search_strings[0],
                   'detailed': detailed,
                   'exact_match': exact_match,
                   'search_string': search_strings}
@@ -88,25 +113,6 @@ def watch_process(search_strings, service=None, component=None,
     return config
 
 
-def watch_process_by_username(username, process_name, service=None, component=None, detailed=False):
-    """Takes a user and returns a Plugins object with the config set for a process check by user.
-        This was built as a helper as many plugins setup process watching.
-    """
-    config = agent_config.Plugins()
-
-    parameters = {'name': process_name,
-                  'detailed': detailed,
-                  'username': username}
-
-    dimensions = _get_dimensions(service, component)
-    if len(dimensions) > 0:
-        parameters['dimensions'] = dimensions
-
-    config['process'] = {'init_config': None,
-                         'instances': [parameters]}
-    return config
-
-
 def service_api_check(name, url, pattern, service=None, component=None):
     """Setup a service api to be watched by the http_check plugin.
     """
